<?php
/**
 * Banner Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Banner section
$wp_customize->add_section( 'firm_graphy_pro_banner_section', array(
	'title'             => esc_html__( 'Banner','firm-graphy-pro' ),
	'description'       => esc_html__( 'Banner Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Banner content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_section_enable]', array(
	'default'			=> 	$options['banner_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[banner_section_enable]', array(
	'label'             => esc_html__( 'Banner Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_banner_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// Banner content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_content_type]', array(
	'default'          	=> $options['banner_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'firm-graphy-pro' ),
	),
) );

// banner pages drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_content_page]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_banner_section',
	'choices'			=> firm_graphy_pro_page_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_banner_section_content_page_enable',
) ) );

// banner posts drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_content_post]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_banner_section',
	'choices'			=> firm_graphy_pro_post_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_banner_section_content_post_enable',
) ) );

// banner title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[banner_title]', array(
		'selector'            => '#hero-banner .hero-banner-wrapper .entry-header h2.entry-title',
		'settings'            => 'firm_graphy_pro_theme_options[banner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_banner_title_partial',
    ) );
}

// banner description setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['banner_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_description]', array(
	'label'           	=> esc_html__( 'Description', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[banner_description]', array(
		'selector'            => '#hero-banner .hero-banner-wrapper .entry-content p',
		'settings'            => 'firm_graphy_pro_theme_options[banner_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_banner_description_partial',
    ) );
}

// banner image setting and control.
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_image]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'firm_graphy_pro_theme_options[banner_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'firm-graphy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'firm-graphy-pro' ), 717, 520 ),
		'section'     		=> 'firm_graphy_pro_banner_section',
		'active_callback'	=> 'firm_graphy_pro_is_banner_section_content_custom_enable',
) ) );

// Banner btn label setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_btn_label]', array(
	'label'           	=> esc_html__( 'Primary Button Label', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[banner_btn_label]', array(
		'selector'            => '#hero-banner .hero-banner-wrapper .buttons a.btn-transparent',
		'settings'            => 'firm_graphy_pro_theme_options[banner_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_banner_btn_label_partial',
    ) );
}

// Banner btn link setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_btn_url]', array(
	'label'           	=> esc_html__( 'Primary Button Link', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_content_custom_enable',
	'type'				=> 'url',
) );

// banner hr setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Customize_Horizontal_Line( $wp_customize, 'firm_graphy_pro_theme_options[banner_hr]',
	array(
		'section'         => 'firm_graphy_pro_banner_section',
		'active_callback' => 'firm_graphy_pro_is_banner_section_enable',
		'type'			  => 'hr'
) ) );

// Banner btn label setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[alt_banner_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['alt_banner_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[alt_banner_btn_label]', array(
	'label'           	=> esc_html__( 'Secondary Button Label', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[alt_banner_btn_label]', array(
		'selector'            => '#hero-banner .hero-banner-wrapper .buttons a.btn-default',
		'settings'            => 'firm_graphy_pro_theme_options[alt_banner_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_alt_banner_btn_label_partial',
    ) );
}

// Banner btn link setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[alt_banner_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[alt_banner_btn_url]', array(
	'label'           	=> esc_html__( 'Secondary Button Link', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'type'				=> 'url',
) );

// banner hr setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_hr_1]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Customize_Horizontal_Line( $wp_customize, 'firm_graphy_pro_theme_options[banner_hr_1]',
	array(
		'section'         => 'firm_graphy_pro_banner_section',
		'active_callback' => 'firm_graphy_pro_is_banner_section_enable',
		'type'			  => 'hr'
) ) );

// Banner address setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_address]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_address'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_address]', array(
	'label'           	=> esc_html__( 'Address', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[banner_address]', array(
		'selector'            => '#hero-banner .address-block .address',
		'settings'            => 'firm_graphy_pro_theme_options[banner_address]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_banner_address_partial',
    ) );
}

// Banner contact setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[banner_contact]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_contact'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[banner_contact]', array(
	'label'           	=> esc_html__( 'Contact', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_banner_section',
	'active_callback' 	=> 'firm_graphy_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[banner_contact]', array(
		'selector'            => '#hero-banner .address-block .phone',
		'settings'            => 'firm_graphy_pro_theme_options[banner_contact]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_banner_contact_partial',
    ) );
}