<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Client section
$wp_customize->add_section( 'firm_graphy_pro_client_section', array(
	'title'             => esc_html__( 'Client','firm-graphy-pro' ),
	'description'       => esc_html__( 'Client Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Client content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_section_enable]', array(
	'default'			=> 	$options['client_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'Client Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_client_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// client title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['client_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[client_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_client_section',
	'active_callback' 	=> 'firm_graphy_pro_is_client_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[client_title]', array(
		'selector'            => '#client-slider .section-header h2.section-title',
		'settings'            => 'firm_graphy_pro_theme_options[client_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_client_title_partial',
    ) );
}

// Client content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_content_type]', array(
	'default'          	=> $options['client_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[client_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_client_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_client_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'category' 	=> esc_html__( 'Category', 'firm-graphy-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'firm-graphy-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_count]', array(
	'default'          	=> $options['client_count'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_number_range',
	'validate_callback' => 'firm_graphy_pro_validate_client_count',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[client_count]', array(
	'label'             => esc_html__( 'Number of Clients', 'firm-graphy-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_client_section',
	'active_callback'   => 'firm_graphy_pro_is_client_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'firm_graphy_pro_theme_options[client_content_category]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Taxonomies_Control( $wp_customize,'firm_graphy_pro_theme_options[client_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'firm-graphy-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_client_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'firm_graphy_pro_is_client_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['client_count']; $i++ ) :
	// client pages drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_content_page_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[client_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_client_section',
		'choices'			=> firm_graphy_pro_page_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_client_section_content_page_enable',
	) ) );

	// client posts drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_content_post_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[client_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_client_section',
		'choices'			=> firm_graphy_pro_post_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_client_section_content_post_enable',
	) ) );

	// client image setting and control.
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_image_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'firm_graphy_pro_theme_options[client_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'firm-graphy-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'firm-graphy-pro' ), 200, 125 ),
			'section'     		=> 'firm_graphy_pro_client_section',
			'active_callback'	=> 'firm_graphy_pro_is_client_section_content_custom_enable',
	) ) );

	// client alt text setting and control
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'firm_graphy_pro_theme_options[client_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Alternative Text %d', 'firm-graphy-pro' ), $i ),
		'section'        	=> 'firm_graphy_pro_client_section',
		'active_callback' 	=> 'firm_graphy_pro_is_client_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// client position setting and control
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'firm_graphy_pro_theme_options[client_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'firm-graphy-pro' ), $i ),
		'section'        	=> 'firm_graphy_pro_client_section',
		'active_callback' 	=> 'firm_graphy_pro_is_client_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// client hr setting and control
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[client_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Customize_Horizontal_Line( $wp_customize, 'firm_graphy_pro_theme_options[client_hr_'. $i .']',
		array(
			'section'         => 'firm_graphy_pro_client_section',
			'active_callback' => 'firm_graphy_pro_is_client_section_content_custom_enable',
			'type'			  => 'hr'
	) ) );
endfor;

