<?php
/**
 * Introduction Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Introduction section
$wp_customize->add_section( 'firm_graphy_pro_introduction_section', array(
	'title'             => esc_html__( 'Introduction','firm-graphy-pro' ),
	'description'       => esc_html__( 'Introduction Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Introduction content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_section_enable]', array(
	'default'			=> 	$options['introduction_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[introduction_section_enable]', array(
	'label'             => esc_html__( 'Introduction Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_introduction_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// Introduction content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_content_type]', array(
	'default'          	=> $options['introduction_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[introduction_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_introduction_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_introduction_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'firm-graphy-pro' ),
	),
) );

// introduction pages drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_content_page]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[introduction_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_introduction_section',
	'choices'			=> firm_graphy_pro_page_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_introduction_section_content_page_enable',
) ) );

// introduction posts drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_content_post]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[introduction_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_introduction_section',
	'choices'			=> firm_graphy_pro_post_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_introduction_section_content_post_enable',
) ) );

// introduction title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[introduction_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_introduction_section',
	'active_callback' 	=> 'firm_graphy_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[introduction_title]', array(
		'selector'            => '#work-experience .work-section-wrapper .section-header h2.section-title',
		'settings'            => 'firm_graphy_pro_theme_options[introduction_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_introduction_title_partial',
    ) );
}

// introduction description setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['introduction_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[introduction_description]', array(
	'label'           	=> esc_html__( 'Description', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_introduction_section',
	'active_callback' 	=> 'firm_graphy_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[introduction_description]', array(
		'selector'            => '#work-experience .work-section-wrapper .section-content p',
		'settings'            => 'firm_graphy_pro_theme_options[introduction_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_introduction_description_partial',
    ) );
}

// introduction image setting and control.
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_image]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'firm_graphy_pro_theme_options[introduction_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'firm-graphy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'firm-graphy-pro' ), 717, 520 ),
		'section'     		=> 'firm_graphy_pro_introduction_section',
		'active_callback'	=> 'firm_graphy_pro_is_introduction_section_content_custom_enable',
) ) );

// Introduction btn label setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[introduction_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_introduction_section',
	'active_callback' 	=> 'firm_graphy_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[introduction_btn_label]', array(
		'selector'            => '#work-experience .work-section-wrapper a.btn-primary',
		'settings'            => 'firm_graphy_pro_theme_options[introduction_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_introduction_btn_label_partial',
    ) );
}

// Introduction btn link setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[introduction_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[introduction_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_introduction_section',
	'active_callback' 	=> 'firm_graphy_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'url',
) );
