<?php
/**
 * Latest Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Latest section
$wp_customize->add_section( 'firm_graphy_pro_latest_section', array(
	'title'             => esc_html__( 'Latest Projects','firm-graphy-pro' ),
	'description'       => esc_html__( 'Latest Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Latest content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_section_enable]', array(
	'default'			=> 	$options['latest_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_latest_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// latest title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_latest_section',
	'active_callback' 	=> 'firm_graphy_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[latest_title]', array(
		'selector'            => '#project .section-header h2.section-title',
		'settings'            => 'firm_graphy_pro_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_latest_title_partial',
    ) );
}

// latest number control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_count]', array(
	'default'          	=> $options['latest_count'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_number_range',
	'validate_callback' => 'firm_graphy_pro_validate_latest_count',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[latest_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'firm-graphy-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_latest_section',
	'active_callback'   => 'firm_graphy_pro_is_latest_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Latest content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_content_type]', array(
	'default'          	=> $options['latest_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[latest_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_latest_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'category' 	=> esc_html__( 'Category', 'firm-graphy-pro' ),
	),
) );

for ( $i = 1; $i <= $options['latest_count']; $i++ ) :
	// latest pages drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_content_page_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[latest_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_latest_section',
		'choices'			=> firm_graphy_pro_page_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_latest_section_content_page_enable',
	) ) );

	// latest posts drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[latest_content_post_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[latest_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_latest_section',
		'choices'			=> firm_graphy_pro_post_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_latest_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'firm_graphy_pro_theme_options[latest_content_category]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Taxonomies_Control( $wp_customize,'firm_graphy_pro_theme_options[latest_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'firm-graphy-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_latest_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'firm_graphy_pro_is_latest_section_content_category_enable'
) ) );
