<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */
if ( ! function_exists( 'firm_graphy_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Firm Graphy Pro 1.0.0
    */
    function firm_graphy_pro_add_counter_section() {
    	$options = firm_graphy_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'firm_graphy_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        firm_graphy_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'firm_graphy_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Firm Graphy Pro 1.0.0
   *
   */
   function firm_graphy_pro_render_counter_section() {
        $options = firm_graphy_pro_get_theme_options();
        $image = ! empty( $options['counter_image'] ) ? $options['counter_image'] : '';
        
        $col = 0;
        for ( $i = 1; $i <= 4 ; $i++) { 
            if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : 
                $col++;
            endif; 
        } 

        if ( 0 === $col ) {
            return;
        }
        ?>

        <div id="counter" class="relative page-section col-<?php echo absint( $col ); ?>" 
            <?php if ( ! empty( $image ) ) : ?>
                style="background-image: url('<?php echo esc_url( $image ); ?>');"
            <?php endif; ?>
        >
                <!-- supports col-1, col-2, col-3, col-4 -->
            <div class="wrapper">
                <?php for ( $i = 1; $i <= 4 ; $i++) { 
                    if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : ?>
                        <div class="counter-item hentry">    
                            <span class="stat-count"><?php echo esc_html( $options['counter_value_' . $i] ); ?></span>
                            <small><?php echo esc_html( $options['counter_label_' . $i] ); ?></small>
                        </div><!-- .counter-item -->
                    <?php endif; 
                } ?>
            </div><!-- .wrapper -->
        </div><!-- #counter -->

    <?php }
endif;