<?php
/**
 * Featured Intro section
 *
 * This is the template for the content of featured_intro section
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */
if ( ! function_exists( 'firm_graphy_pro_add_featured_intro_section' ) ) :
    /**
    * Add featured_intro section
    *
    *@since Firm Graphy Pro 1.0.0
    */
    function firm_graphy_pro_add_featured_intro_section() {
    	$options = firm_graphy_pro_get_theme_options();
        // Check if featured_intro is enabled on frontpage
        $featured_intro_enable = apply_filters( 'firm_graphy_pro_section_status', true, 'featured_intro_section_enable' );

        if ( true !== $featured_intro_enable ) {
            return false;
        }
        // Get featured_intro section details
        $section_details = array();
        $section_details = apply_filters( 'firm_graphy_pro_filter_featured_intro_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_intro section now.
        firm_graphy_pro_render_featured_intro_section( $section_details );
    }
endif;

if ( ! function_exists( 'firm_graphy_pro_get_featured_intro_section_details' ) ) :
    /**
    * featured_intro section details.
    *
    * @since Firm Graphy Pro 1.0.0
    * @param array $input featured_intro section details.
    */
    function firm_graphy_pro_get_featured_intro_section_details( $input ) {
        $options = firm_graphy_pro_get_theme_options();

        // Content type.
        $featured_intro_content_type  = $options['featured_intro_content_type'];
        
        $content = array();
        switch ( $featured_intro_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['featured_intro_content_page'] ) ? $options['featured_intro_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['featured_intro_content_post'] ) ? $options['featured_intro_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'custom':
                $custom['title']      = ! empty( $options['featured_intro_title'] ) ? $options['featured_intro_title'] : '';
                $custom['excerpt']    = ! empty( $options['featured_intro_description'] ) ? $options['featured_intro_description'] : '';
                $custom['image']      = ! empty( $options['featured_intro_image'] ) ? $options['featured_intro_image'] : '';
                $custom['url']        = ! empty( $options['featured_intro_btn_url'] ) ? $options['featured_intro_btn_url'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            default:
            break;
        }

        if ( 'custom' !== $featured_intro_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = firm_graphy_pro_trim_content( 50 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_intro section content details.
add_filter( 'firm_graphy_pro_filter_featured_intro_section_details', 'firm_graphy_pro_get_featured_intro_section_details' );


if ( ! function_exists( 'firm_graphy_pro_render_featured_intro_section' ) ) :
  /**
   * Start featured_intro section
   *
   * @return string featured_intro content
   * @since Firm Graphy Pro 1.0.0
   *
   */
   function firm_graphy_pro_render_featured_intro_section( $content_details = array() ) {
        $options = firm_graphy_pro_get_theme_options();
        $btn_label = ! empty( $options['featured_intro_btn_label'] ) ? $options['featured_intro_btn_label'] : esc_html__( 'Read More', 'firm-graphy-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="choose-us" class="relative page-section">
                <div class="wrapper">
                    <div class="choose-section-wrapper <?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-featured-image">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            </div>
                        <?php endif; ?>

                        <div class="entry-container">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; 

                            if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .section-content -->
                            <?php endif; 

                            if ( ! empty( $content['url'] ) ) : ?>
                               <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $btn_label ); ?></a>
                           <?php endif; ?>
                        </div><!-- .entry-container -->
                    </div><!-- .work-section-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #choose-us -->
        <?php endforeach;
    }
endif;